@@ -14,9 +14,7 @@ sub location_section_contents {
 
 sub httpd_conf_start {
 	my ($self, $res) = @_;
-	my $sc = Apache::SWIT::Maker::Config->instance->session_class;
 	$res = read_file('conf/httpd.conf.in') . "\n";
-	$res =~ s/\@SessionClass\@/$sc/g;
 	return $res;
 }
 
