@@ -11,7 +11,7 @@ use warnings FATAL => 'all';
 
 package [% class_v %]::Root;
 use base 'HTML::Tested::ClassDBI';
-use [% root_class_v %]::DB::[% table_class_v %];
+use [% db_class_v %];
 
 __PACKAGE__->ht_add_widget(::HTV."::Hidden", 'ht_id', cdbi_bind => 'Primary');
 __PACKAGE__->ht_add_widget(::HTV."::Submit", 'submit_button'
@@ -22,7 +22,7 @@ __PACKAGE__->ht_add_widget(::HTV."::Form", form => default_value => 'u');
 [% FOREACH fields_v %]
 __PACKAGE__->ht_add_widget(::HTV."::EditBox"
 			, [% field %] => cdbi_bind => '');[% END %]
-__PACKAGE__->bind_to_class_dbi('[% root_class_v %]::DB::[% table_class_v %]');
+__PACKAGE__->bind_to_class_dbi('[% db_class_v %]');
 
 package [% class_v %];
 use base qw(Apache::SWIT::HTPage);
